/**
 * Copyright (c) 2012, John Simone
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 *    Redistributions of source code must retain the above copyright notice, this list of conditions and the
 *    following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *    Neither the name of John Simone nor the names of its contributors may be used to endorse or
 *    promote products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package webapp.runner.launch;

import java.util.HashMap;
import java.util.Map;

/**
 * Util class for parsing arguments from the command line.
 * 
 * @author johnsimone
 *
 */
public class ArgParser {
	
	/**
	 * Parse the argument list. The Argument enum takes care of deciding which arguments
	 * are understood
	 * 
	 * @param args
	 * @return
	 * @throws ArgumentNotFoundException
	 */
	public static Map<Argument, String> parseArgs(String[] args) throws ArgumentNotFoundException, MissingAppException {
		Map<Argument, String> argMap = new HashMap<Argument, String>();
		
		for(int i=0; i < args.length-1; i+=2) {
			argMap.put(Argument.getArgFor(args[i]), args[i+1]);
		}

		//if there are even number of arguments then we didn't define the app location
		if(args.length % 2 == 0 || args[args.length-1].startsWith("--")) {
			throw new MissingAppException();
		}
		
		argMap.put(Argument.APPLICATION_DIR, args[args.length-1]);
		
		return argMap;
	}
	
}
